==> client-java-api-fluent-16.0.2-sources.jar: io/kubernetes/client/openapi/models/V1CronJobBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1CronJobBuilder extends V1CronJobFluentImpl<V1CronJobBuilder>
    implements VisitableBuilder<V1CronJob, io.kubernetes.client.openapi.models.V1CronJobBuilder> {
  public V1CronJobBuilder() {
    this(false);
  }

  public V1CronJobBuilder(Boolean validationEnabled) {
    this(new V1CronJob(), validationEnabled);
  }

  public V1CronJobBuilder(io.kubernetes.client.openapi.models.V1CronJobFluent<?> fluent) {
    this(fluent, false);
  }

  public V1CronJobBuilder(
      io.kubernetes.client.openapi.models.V1CronJobFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1CronJob(), validationEnabled);
  }

  public V1CronJobBuilder(
      io.kubernetes.client.openapi.models.V1CronJobFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1CronJob instance) {
    this(fluent, instance, false);
  }

  public V1CronJobBuilder(
      io.kubernetes.client.openapi.models.V1CronJobFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1CronJob instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    fluent.withSpec(instance.getSpec());

    fluent.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled;
  }

  public V1CronJobBuilder(io.kubernetes.client.openapi.models.V1CronJob instance) {
    this(instance, false);
  }

  public V1CronJobBuilder(
      io.kubernetes.client.openapi.models.V1CronJob instance, java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withApiVersion(instance.getApiVersion());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.withSpec(instance.getSpec());

    this.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1CronJobFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1CronJob build() {
    V1CronJob buildable = new V1CronJob();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    buildable.setSpec(fluent.getSpec());
    buildable.setStatus(fluent.getStatus());
    return buildable;
  }
}

==> client-java-api-fluent-17.0.2-sources.jar: io/kubernetes/client/openapi/models/V1CronJobBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1CronJobBuilder extends V1CronJobFluentImpl<V1CronJobBuilder> implements VisitableBuilder<V1CronJob,V1CronJobBuilder>{
  public V1CronJobBuilder() {
    this(false);
  }
  public V1CronJobBuilder(Boolean validationEnabled) {
    this(new V1CronJob(), validationEnabled);
  }
  public V1CronJobBuilder(V1CronJobFluent<?> fluent) {
    this(fluent, false);
  }
  public V1CronJobBuilder(V1CronJobFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1CronJob(), validationEnabled);
  }
  public V1CronJobBuilder(V1CronJobFluent<?> fluent,V1CronJob instance) {
    this(fluent, instance, false);
  }
  public V1CronJobBuilder(V1CronJobFluent<?> fluent,V1CronJob instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    fluent.withSpec(instance.getSpec());

    fluent.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled; 
  }
  public V1CronJobBuilder(V1CronJob instance) {
    this(instance,false);
  }
  public V1CronJobBuilder(V1CronJob instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.withSpec(instance.getSpec());

    this.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled; 
  }
  V1CronJobFluent<?> fluent;
  Boolean validationEnabled;
  public V1CronJob build() {
    V1CronJob buildable = new V1CronJob();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    buildable.setSpec(fluent.getSpec());
    buildable.setStatus(fluent.getStatus());
    return buildable;
  }
  
}
